<?php

/**
 * Content Plugin for Joomla - IntroMarker
 *
 * @author Frits Jongbloets (oorzaak@oorzaak.nl)
 * @copyright Copyright 2017 Frits Jongbloets
 * @licence GNU Public Licence version 3 or later
 */

defined('_JEXEC') or die('Direct access not allowed');

//  to do: pull-left / pull-right depending on the presence of an image tag?

jimport('joomla.plugin.plugin');

class PlgContentIntromarker extends JPlugin{

    //	constructor
    public function __construct(& $subject, $config)
    {
        parent::__construct($subject, $config);
        $this->loadLanguage();

        $this->category_filter      = $this->params->get('category_filter');
        $this->category             = $this->params->get('category');
        //  to do: use category as main categorie, i.e. also include child categories
        //  copy function from odv plugin
        $this->intro_category_class = $this->params->get('intro_category_class');
        $this->intro_article_class  = $this->params->get('intro_article_class');
        $this->divider_class        = $this->params->get('divider_class');
    }

    //  adding css in head
    public function onBeforeCompileHead()
    {
        //  getting some context
        $jinput = JFactory::getApplication()->input;
        $view = $jinput->get('view', '', 'word');
        $option = $jinput->get('option', '', 'word');

        //  only in front end
        $app = JFactory::getApplication();
        if(!$app->isSite())
        {
            return true;
        }

        //  only in com_content article and category views
        if(!$option=='com_content' AND !$view=='article' AND !$view=='category')
        {
            return true;
        }

        //  We've passed all checks, now execute scripts
        $document = JFactory::getDocument();
        $style = $this ->createCss();

        $document->addStyleDeclaration( $style );

        return true;
    }

    //	adding divs in body
    public function onContentPrepare($context, &$row, $params, $page=0){

        $app = JFactory::getApplication();
        if(!$app->isSite())
        {
            return true;
        }

        //  only in com_content article and category views
        if($context != 'com_content.article' and $context != 'com_content.category')
        {
            return true;
        }

        //  optionally: using category filter
        if($this->category_filter == 1)
        {
            if($row->catid != $this->category)
            {
                return true;
            }
        }
        elseif($this->category_filter == 2)
        {
            if($row->catid == $this->category)
            {
                return true;
            }
        }


        //  We've passed all checks, now execute script
        if($context=='com_content.article')
        {
            $new_intro = '<div class="custom-introtext-article '. $this->intro_article_class . '">';
            $new_intro.= $row->introtext . '</div>';
            $new_intro.= '<div class="custom-divider '. $this->divider_class . '">&nbsp;</div>';

            $row->text = $new_intro . $row->fulltext;
        }

        if($context=='com_content.category')
        {
            if($row->catid ==  $this->category)
            {
                $new_intro = '<div class="custom-introtext-category '. $this->intro_category_class . '">';
                $new_intro.= $row->introtext . '</div>';

                $row->text = $new_intro;
            }
        }

        return true;
    }

    /* some functions for specific tasks: */

    private function createCss()
    {
        $css = '
            .custom-divider{
                float:none;
                clear:both;
            }
        ';

        return $css;
    }

}


